<?php
/*
 Plugin Name: eCredits
 Plugin URI: https://ecredits.com/en/merchants/
 Description: Become part of the future today! Accept eCredits (ECS) in your onlineshop. The easy-to-use plugin allows you to offer your customers to checkout with ECS. Simple and quick installation. Learn more in our User Guide.
 Version: 1.0.3
 Author: eCredits
 Author URI: https://ecredits.com
 License: GPLv2 or later
 Text Domain: crypto-payment
 */
/**
 * Class ECWP_Payment_Crypto file.
 *
 * @package WooCommerce\Crypto
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

// Act on plugin activation
register_activation_hook( __FILE__, "ecwp_activate" );

// Act on plugin de-activation
register_deactivation_hook( __FILE__, "ecwp_deactivate" );

// Activate Plugin
function ecwp_activate() {
    // Insert DB Tables
    ecwp_init_db_crypto();
}

// De-activate Plugin
function ecwp_deactivate() {

    // Execute tasks on Plugin de-activation
}

if(!in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) return;

add_action('plugins_loaded', 'ecwp_payment_gateway_init', 11);
add_action('wp_enqueue_scripts','ecwp_script_init');

function ecwp_script_init() {
    wp_enqueue_script( 'timer-js', plugins_url( 'js/timer.js', __FILE__ ));
    wp_enqueue_script( 'orderStatus-js', plugins_url( 'js/orderStatus.js', __FILE__ ));
}

function ecwp_payment_gateway_init()
{
    if (class_exists('WC_Payment_Gateway')) {
    require_once plugin_dir_path(__FILE__) . '/includes/class_crypto_payment_gateway.php';
    }
}

add_filter('woocommerce_payment_gateways', 'ecwp_add_to_payment_gateway');

function ecwp_add_to_payment_gateway($gateways) {
    $gateways[] = "ECWP_Payment_Crypto";
    return $gateways;
}

function ecwp_init_db_crypto() {
    // WP Globals
    global $table_prefix, $wpdb;

    // Customer Table
    $customerTable = $table_prefix . 'e_credits_transactions';

    // Create Customer Table if not exist
    if( $wpdb->get_var( "show tables like '$customerTable'" ) != $customerTable ) {

        // Query - Create Table
        $sql = "CREATE TABLE `$customerTable` (";
        $sql .= " `id` int(11) NOT NULL auto_increment, ";
        $sql .= " `order_id` int(11) NOT NULL, ";
        $sql .= " `timestamp` int(50) NOT NULL, ";
        $sql .= " `transaction_id` varchar(50) NOT NULL, ";
        $sql .= " `qrCodeBase64` text NOT NULL, ";
        $sql .= " `expiresAt` varchar(255) NOT NULL, ";
        $sql .= " `total` float NOT NULL, ";
        $sql .= " `totalCurrency` varchar(255) NOT NULL, ";
        $sql .= " `totalFiat` float NOT NULL, ";
        $sql .= " `totalFiatCurrency` varchar(255) NOT NULL, ";
        $sql .= " PRIMARY KEY `id` (`id`) ";
        $sql .= ") ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1;";

        // Include Upgrade Script
        require_once( ABSPATH . '/wp-admin/includes/upgrade.php' );

        // Create Table
        dbDelta( $sql );
    }

}
